pub struct BlackBoxApp { /* private fields */ }Implementations
Sourceimpl BlackBoxApp
impl BlackBoxApp
pub fn new(container: RefMut<Container>) -> BlackBoxApp
pub fn get_container(&self) -> RefMut<Container>
Sourcepub fn get<TInjectable: CastFrom>(&self) -> Result<Ref<TInjectable>, String>
pub fn get<TInjectable: CastFrom>(&self) -> Result<Ref<TInjectable>, String>
Retrieves an instance of either injectable, otherwise, throws error.
Sourcepub fn get_by_token<TInjectable: ?Sized + CastFrom>(
&self,
token: &InstanceToken,
) -> Result<Ref<TInjectable>, String>
pub fn get_by_token<TInjectable: ?Sized + CastFrom>( &self, token: &InstanceToken, ) -> Result<Ref<TInjectable>, String>
Retrieves an instance of either injectable by token, otherwise, throws error.
pub fn use_logger(&self, logger: Ref<dyn ILogger>)